.. :changelog:

History
-------

0.4.1 (2017-10-26)
++++++++++++++++++

* Improve Unicode handling on Python 2, allowing the Printings admin
  page to load properly (`#27`_).

.. _#27: https://github.com/pbaranay/django-magic-cards/issues/27

0.4.0 (2017-10-04)
++++++++++++++++++

* Update a `Card`'s data (text, loyalty, types, etc.) when a set is re-imported (`#23`_).

.. _#23: https://github.com/pbaranay/django-magic-cards/issues/23

0.3.0 (2017-09-28)
++++++++++++++++++

* Store planeswalkers' starting loyalty (`#19`_).
* Correctly populate flavor text.
* Fix issue that crashed re-importing a set without multiverse IDs.

.. _#19: https://github.com/pbaranay/django-magic-cards/issues/19

0.2.0 (2017-08-16)
++++++++++++++++++

* Speed up import function (`#9`_).
* Implement basic admin pages (`#7`_).

.. _#9: https://github.com/pbaranay/django-magic-cards/issues/9
.. _#7: https://github.com/pbaranay/django-magic-cards/issues/7

0.1.1 (2017-08-10)
++++++++++++++++++

* Increase maximum length of a `Card`'s `name` (`#2`_).

.. _#2: https://github.com/pbaranay/django-magic-cards/issues/2

0.1.0 (2017-08-08)
++++++++++++++++++

* First release on PyPI.
